@@ -161,7 +161,16 @@ class App(object):
         return pipeline
     default_pipeline = property(_get_default_pipeline)
 
-    def handle_command_line(self, cmd_line_parts=None, program=None, exit=sys.exit):
+    def handle_command_line(self, cmd_line_parts=None, program=None, exit=None, **commandtool_args):
+        """\
+        Usual use is:
+
+        ::
+
+            result = handle_command_line(...)
+            sys.exit(result)
+
+        """
         if not self._commands_structure:
             raise Exception('No commands specified in the app')
         else:
@@ -192,9 +201,12 @@ class App(object):
                     program=program,
                     service=self,
                     cmd_line_parts=cmd_line_parts,
+                    **commandtool_args
                 ))
             self.start_flow(bag=None, ensure=[], run=run)
-            exit(result[0])
+            if exit:
+                exit(result[0])
+            return result[0]
 
     def start_flow(self, bag=None, ensure=[], run=None):
         for name in ensure:
